==> qtjambi-qt3drender-6.3.0-sources.jar: io/qt/qt3d/render/PropertyReaderInterface.java <==
package io.qt.qt3d.render;


/**
 * <p>Java wrapper for Qt class Qt3DRender::PropertyReaderInterface</p>
 */
public interface PropertyReaderInterface extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.PropertyReaderInterface}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qt3d.render.PropertyReaderInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends PropertyReaderInterface.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.Object readProperty(java.lang.Object v){
                return readProperty_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), v);
            }
            private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(PropertyReaderInterface instance);
        
        @io.qt.QtUninvokable
        public abstract java.lang.Object readProperty(java.lang.Object v);
        
        private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @io.qt.QtUninvokable
    public java.lang.Object readProperty(java.lang.Object v);
    
}

==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/PropertyReaderInterface.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class Qt3DRender::PropertyReaderInterface</p>
 */
public interface PropertyReaderInterface extends QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.PropertyReaderInterface}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.qt3d.render.PropertyReaderInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @NativeAccess
        private static final class ConcreteWrapper extends PropertyReaderInterface.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public java.lang.Object readProperty(java.lang.Object v){
                return readProperty_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), v);
            }
            private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(PropertyReaderInterface instance);
        
        @QtUninvokable
        public abstract java.lang.Object readProperty(java.lang.Object v);
        
        private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @QtUninvokable
    public java.lang.Object readProperty(java.lang.Object v);
    
}
